@@ -16,9 +16,12 @@ check_cluto_path = function() {
           package = "mlr3spatiotempcv"))
       }, # nocov end
       "Linux" = {
+        if (Sys.info()[["machine"]] != "x86_64") {
+          stopf("CLUTO on Linux only works on x86_64 architecture.")
+        }
         if (!file.exists(system.file("vcluster",
           package = "mlr3spatiotempcv"))) {
-          stopf("vcluster.exe not found. Please install CLUTO first.
+          stopf("vcluster executable not found. Please install CLUTO first.
             See ?ResamplingSptCVCluto for instructions.", wrap = TRUE)
         }
         # nocov start
@@ -31,3 +34,7 @@ check_cluto_path = function() {
   }
   return(vcluster_loc)
 }
+
+catn = function(..., file = "") {
+  cat(paste0(..., collapse = "\n"), "\n", sep = "", file = file)
+}
