@@ -8,12 +8,12 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
+## ---- include=FALSE-----------------------------------------------------------
+library(mlr3spatiotempcv)
+
 ## -----------------------------------------------------------------------------
 mlr_reflections$task_types
 
 ## -----------------------------------------------------------------------------
 mlr_reflections$task_col_roles
 
-## ---- warning=FALSE-----------------------------------------------------------
-as.data.table(mlr_resamplings)
-
