@@ -1,9 +1,11 @@
+# nocov start
+
 test_that("folds can be printed", {
   skip_on_cran()
   skip_on_os("mac")
-  task = tsk("cookfarm")
-  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5, time_var = "Date")
-  rsp$instantiate(task)
+  skip_if_not_installed("skmeans")
+  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5)
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$folds(4:8), c(1, 2, 3, 1, 2))
 })
@@ -11,9 +13,9 @@ test_that("folds can be printed", {
 test_that("reps and folds can be printed", {
   skip_on_cran()
   skip_on_os("mac")
-  task = tsk("cookfarm")
-  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5, time_var = "Date")
-  rsp$instantiate(task)
+  skip_if_not_installed("skmeans")
+  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5)
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$repeats(4:8), c(2, 2, 2, 3, 3))
   expect_equal(rsp$folds(10), 1)
@@ -22,9 +24,9 @@ test_that("reps and folds can be printed", {
 test_that("resampling iterations equals folds * repeats", {
   skip_on_cran()
   skip_on_os("mac")
-  task = tsk("cookfarm")
-  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5, time_var = "Date")
-  rsp$instantiate(task)
+  skip_if_not_installed("skmeans")
+  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5)
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$iters, 15)
 })
@@ -32,9 +34,11 @@ test_that("resampling iterations equals folds * repeats", {
 test_that("resampling iterations equals folds * repeats", {
   skip_on_cran()
   skip_on_os("mac")
-  task = tsk("cookfarm")
-  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5, time_var = "Date")
-  rsp$instantiate(task)
+  skip_if_not_installed("skmeans")
+  rsp = rsmp("repeated_sptcv_cluto", folds = 3, repeats = 5)
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$iters, 15)
 })
+
+# nocov end
