@@ -1,12 +1,16 @@
 # spatiotemporal ---------------------------------------------------------------
 
+# nocov start
+
 test_that("resampling iterations equals folds", {
   skip_on_cran()
   skip_on_os("mac")
+  skip_if_not_installed("skmeans")
+  skip_if_not_installed("mlr3pipelines")
+  skip_if(Sys.info()[["machine"]] != "x86_64")
 
-  task = tsk("cookfarm")
-  rsp = rsmp("sptcv_cluto", folds = 2, time_var = "Date")
-  rsp$instantiate(task)
+  rsp = rsmp("sptcv_cluto", folds = 2)
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$iters, 2)
 })
@@ -14,12 +18,13 @@ test_that("resampling iterations equals folds", {
 test_that("reps can be printed", {
   skip_on_cran()
   skip_on_os("mac")
+  skip_if_not_installed("skmeans")
+  skip_if(Sys.info()[["machine"]] != "x86_64")
 
-  task = tsk("cookfarm")
   rsp = rsmp("repeated_sptcv_cluto",
-    folds = 3, repeats = 5,
-    time_var = "Date")
-  rsp$instantiate(task)
+    folds = 3, repeats = 5
+  )
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$repeats(4:8), c(2, 2, 2, 3, 3))
 })
@@ -27,37 +32,30 @@ test_that("reps can be printed", {
 test_that("resampling iterations equals folds * repeats", {
   skip_on_cran()
   skip_on_os("mac")
+  skip_if_not_installed("skmeans")
+  skip_if(Sys.info()[["machine"]] != "x86_64")
 
-  task = tsk("cookfarm")
   rsp = rsmp("repeated_sptcv_cluto",
-    folds = 3, repeats = 2,
-    time_var = "Date")
-  rsp$instantiate(task)
+    folds = 3, repeats = 2
+  )
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$iters, 6)
 })
 
-test_that("check_cluto_path() works", {
-  skip_on_cran()
-  skip_on_os("mac")
-  withr::with_envvar(c("CLUTO_PATH" = ""), {
-    task = tsk("cookfarm")
-    rsp = rsmp("sptcv_cluto",
-      folds = 3,
-      time_var = "Date")
-    expect_error(rsp$instantiate(task), "vcluster.exe not found")
-  })
-})
 
 # spatial only -----------------------------------------------------------------
 
 test_that("clustering on coords only works", {
   skip_on_cran()
   skip_on_os("mac")
+  skip_if_not_installed("skmeans")
+  skip_if(Sys.info()[["machine"]] != "x86_64")
 
-  task = tsk("cookfarm")
   rsp = rsmp("sptcv_cluto", folds = 2)
-  rsp$instantiate(task)
+  rsp$instantiate(task_cluto)
 
   expect_equal(rsp$iters, 2)
 })
+
+# nocov end
