@@ -22,11 +22,9 @@ test_that("tasks created from sf objects do not duplicate rows", {
     id = "sp_regression",
     backend = data,
     target = "response",
-    extra_args = list(
-      coordinate_names = c("x", "y"),
-      crs = "+proj=utm +zone=33 +datum=WGS84 +units=m +no_defs",
-      coords_as_features = FALSE)
-  )
+    coordinate_names = c("x", "y"),
+    crs = "+proj=utm +zone=33 +datum=WGS84 +units=m +no_defs",
+    coords_as_features = FALSE)
 
   expect_equal(nrow(task$data()), nrow(data))
 })
@@ -40,9 +38,10 @@ test_that("extra_args contains default arguments", {
     id = "sp_regression",
     backend = data,
     target = "response",
-    extra_args = list(
-      coordinate_names = c("x", "y"))
+    coordinate_names = c("x", "y")
   )
 
-  expect_equal(task$extra_args, list(coords_as_features = FALSE, crs = NA, coordinate_names = c("x", "y")))
+  expect_equal(task$extra_args, list(crs = NA_character_,
+    coordinate_names = c("x", "y"), coords_as_features = FALSE
+  ))
 })
